Basileus

Struct Basileus 

pub struct Basileus {
    pub config: Config,
    /* private fields */
}
Entry point for the library.

Fields

config: Config

Configurations.

Implementations

Source

impl Basileus

pub async fn exist_pass(&self, user: &str) -> Result<bool, Error>

Whether a user has defined a password for authorization.

pub async fn update_pass( &self, user: &str, pass: &str, ) -> Result<(), UpdatePassError>

Update password for specified user.

pub async fn verify_pass( &self, user: &str, pass: &str, ) -> Result<bool, VerifyPassError>

Verify given password for user.

pub async fn delete_pass(&self, user: &str) -> Result<(), DeletePassError>

Delete a user’s password.

Source

impl Basileus

pub async fn get_perm(&self, user: &str) -> Result<Perm, GetPermError>

Get permissions the user holds, i.e. group names.

pub async fn check_perm( &self, user: &str, req: &Perm, ) -> Result<bool, CheckPermError>

Check if the user has specified permission.

pub async fn set_perm( &self, user: &str, perm: &Perm, ) -> Result<(), SetPermError>

Sets a user’s permission.

pub async fn give_perm( &self, user: &str, perm: &Perm, ) -> Result<(), GivePermError>

Gives new permissions to specified user.

pub async fn revoke_perm( &self, user: &str, perm: &Perm, ) -> Result<(), RevokePermError>

Revoke a user’s certain permissions. This does not result in an error if the permission does not currently exist.

Source

impl Basileus

pub async fn pkce_auth_req( &self, user: &str, pass: &str, code_challenge: CodeChallenge, ) -> Result<String, PkceAuthError>

Handle a PKCE authorization request.

If the authorization is successful, returns a base64URL-encoded authorization code.

pub fn pkce_token_req( &self, code: &str, code_verifier: &str, ) -> Result<String, PkceTokenError>

Handle a PKCE access token request.

A successful request requires a valid previously issued authorization code (through Self::pkce_auth_req) and a matching code verifier.

Returns the token if successful.

Source

impl Basileus

pub fn issue_token(&self, user: &str) -> String

Issue a new token to the specified user.

pub fn invalidate_token(&self, token: &str)

Invalidate a token.

pub fn invalidate_user_token(&self, user: &str)

Invalidate all tokens related to user.

pub fn expire_token(&self, duration: Duration)

Make all tokens older than duration expire.

pub fn verify_token(&self, token: &str) -> Option<String>

Verify token, return the user it belongs to if successful.

Source

impl Basileus

pub async fn exist_user(&self, user: &str) -> Result<bool, Error>

Check whether a user currently exists.

pub async fn create_user(&self, user: &str) -> Result<(), CreateUserError>

Create a new user.

pub async fn delete_user(&self, user: &str) -> Result<(), DeleteUserError>

Delete a user.

Source

impl Basileus

pub async fn new(config: Config) -> Result<Self, Error>

Initialize the library, creating the database if missing.

pub async fn user_cnt(&self) -> Result<i64, Error>

Count the number of users.